@@ -1,8 +1,5 @@
 package Yars::Client;
 
-# ABSTRACT: Yet Another RESTful-Archive Service Client
-our $VERSION = '0.82_02'; # VERSION
-
 use strict;
 use warnings;
 
@@ -19,9 +16,13 @@ use Log::Log4perl qw(:easy);
 use Digest::file qw/digest_file_hex/;
 use Data::Dumper;
 use IO::Uncompress::Gunzip qw(gunzip $GunzipError);
-use Number::Bytes::Human qw( format_bytes parse_bytes );
 use 5.10.0;
 
+our $VERSION = '0.81';
+
+# default max of 10 GB
+$ENV{MOJO_MAX_MESSAGE_SIZE} ||= 1024*1024*1024 * 10;
+
 route_doc upload   => "<filename>";
 route_doc content  => "<filename> <md5>";
 route_doc download => "<filename> <md5> [dir]";
@@ -135,9 +136,7 @@ sub download {
             $url->path("/file/$filename/$md5");
         }
         TRACE "GET $url";
-        my $tx = $self->client->build_tx(GET => $url, { "Connection" => "Close", "Accept-Encoding" => "gzip" } );
-        $tx->res->max_message_size(parse_bytes($self->_config->max_message_size_client(default => 53687091200)));
-        $self->client->start($tx);
+        my $tx = $self->client->get( $url, { "Connection" => "Close", "Accept-Encoding" => "gzip" } );
         $self->res($tx->res);
         $self->tx($tx);
         my $res = $tx->success or do {
@@ -412,15 +411,9 @@ sub remote {
 
 __END__
 
-=pod
-
 =head1 NAME
 
-Yars::Client - Yet Another RESTful-Archive Service Client
-
-=head1 VERSION
-
-version 0.82_02
+Yars::Client -- Yet Another RESTful-Archive Service Client
 
 =head1 SYNOPSIS
 
@@ -467,23 +460,12 @@ version 0.82_02
      { filename => $f1, md5 => $m1 },
      { filename => $f2, md5 => $m2 } ] });
 
+
 =head1 DESCRIPTION
 
 Client for L<Yars>.
 
 =head1 SEE ALSO
 
-L<yarsclient>, L<Clustericious::Client>
-
-=head1 AUTHOR
-
-Graham Ollis <plicease@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2013 by NASA GSFC.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
-=cut
+ L<yarsclient>
+ L<Clustericious::Client>
